@@ -29,15 +29,16 @@
 #' @export
 bed_shuffle <- function(x, genome, incl = NULL, excl = NULL,
                         max_tries = 1000, within = FALSE, seed = 0) {
-
   if (!is.tbl_interval(x)) x <- as.tbl_interval(x)
   if (!is.tbl_genome(genome)) genome <- as.tbl_genome(genome)
 
   # flatten incl and excl
-  if (!is.null(incl))
-      incl <- bed_merge(incl)
-  if (!is.null(excl))
-      excl <- bed_merge(excl)
+  if (!is.null(incl)) {
+    incl <- bed_merge(incl)
+  }
+  if (!is.null(excl)) {
+    excl <- bed_merge(excl)
+  }
 
   # make genome into an interval tbl
   genome_incl <- mutate(genome, start = 0, end = size)
@@ -53,8 +54,9 @@ bed_shuffle <- function(x, genome, incl = NULL, excl = NULL,
     incl <- bed_subtract(incl, excl)
   }
 
-  if (nrow(incl) == 0 || is.null(incl))
+  if (nrow(incl) == 0 || is.null(incl)) {
     stop("no intervals to sample from", call. = FALSE)
+  }
 
   # drops all columns except chrom, start, and end
   res <- shuffle_impl(x, incl, within, max_tries, seed)
@@ -62,7 +64,7 @@ bed_shuffle <- function(x, genome, incl = NULL, excl = NULL,
   # bind original x column data to result (#81)
   res <- bind_cols(res, x[, !colnames(x) %in% colnames(res)])
 
-  res <- tibble::as_tibble(res)
+  res <- as.tbl_interval(res)
 
   res
 }
